#
# spec file for package libgpiod
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libgpiod_soversion 2
%define libgpiodcxx_soversion 1
%define libgpiomockup_soversion 0

# Tests are only available for kernel 5.1+ (so TW only)
%if 0%{?suse_version} > 1500
%bcond_without libgpiod_tests
%else
%bcond_with libgpiod_tests
%endif

Name:           libgpiod
Version:        1.4
Release:        lp151.2.3.1
Summary:        Tools for interacting with the linux GPIO character device
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Url:            https://git.kernel.org/pub/scm/libs/libgpiod/libgpiod.git/
Source0:        https://git.kernel.org/pub/scm/libs/libgpiod/libgpiod.git/snapshot/libgpiod-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  gcc-c++
%if %{with libgpiod_tests}
BuildRequires:  kernel-devel >= 5.1
BuildRequires:  libudev-devel
%else
BuildRequires:  kernel-devel >= 4.8
%endif
BuildRequires:  libkmod-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  python3-devel

%description
The libgpiod library encapsulates the ioctl calls and data structures
of the GPIO character devices, the latter of which superseded the
GPIO sysfs interface in Linux 4.8.

%package -n libgpiod%{libgpiod_soversion}
Summary:        C library for interacting with the linux GPIO character device
Group:          System/Libraries
Conflicts:      libgpiod1

%description -n libgpiod%{libgpiod_soversion}
The libgpiod library encapsulates the ioctl calls and data structures
of the GPIO character devices, the latter of which superseded the
GPIO sysfs interface in Linux 4.8.

C library part.

%package -n libgpiodcxx%{libgpiodcxx_soversion}
Summary:        C++library for interacting with the linux GPIO character device
Group:          System/Libraries
Conflicts:      libgpiod1

%description -n libgpiodcxx%{libgpiodcxx_soversion}
The libgpiod library encapsulates the ioctl calls and data structures
of the GPIO character devices, the latter of which superseded the
GPIO sysfs interface in Linux 4.8.

C++ library part.

%package -n libgpiomockup%{libgpiomockup_soversion}
Summary:        C library for interacting with the linux GPIO character device
Group:          System/Libraries
Conflicts:      libgpiod1

%description -n libgpiomockup%{libgpiomockup_soversion}
The libgpiod library encapsulates the ioctl calls and data structures
of the GPIO character devices, the latter of which superseded the
GPIO sysfs interface in Linux 4.8.

GPIO mockup library part.

%package devel
Summary:        Devel files for libgpiod
Group:          Development/Languages/C and C++
Requires:       %{name}
Requires:       libgpiod%{libgpiod_soversion} = %{version}
Requires:       libgpiodcxx%{libgpiodcxx_soversion} = %{version}

%description devel
The libgpiod library encapsulates the ioctl calls and data structures
of the GPIO character devices, the latter of which superseded the
GPIO sysfs interface in Linux 4.8.

Devel files part.

%package -n python-%{name}
Summary:        Python binding for libgpiod
Group:          Development/Languages/Python

%description -n python-%{name}
The libgpiod library encapsulates the ioctl calls and data structures
of the GPIO character devices, the latter of which superseded the
GPIO sysfs interface in Linux 4.8.

Python binding part.

%prep
%setup -q

%build
./autogen.sh
%configure \
%if %{with libgpiod_tests}
	--enable-tests \
%endif
	--enable-tools=yes \
	--enable-bindings-python \
	--enable-bindings-cxx 
make

%install
%make_install
rm -rf %{buildroot}%{_libdir}/*.{a,la}
rm -rf %{buildroot}%{python3_sitearch}/*.{a,la}

%post -n libgpiod%{libgpiod_soversion} -p /sbin/ldconfig
%postun	-n libgpiod%{libgpiod_soversion} -p /sbin/ldconfig
%post -n libgpiodcxx%{libgpiodcxx_soversion} -p /sbin/ldconfig
%postun	-n libgpiodcxx%{libgpiodcxx_soversion} -p /sbin/ldconfig

%files
%{_bindir}/gpio*

%files -n libgpiod%{libgpiod_soversion}
%{_libdir}/libgpiod.so.*

%files -n libgpiodcxx%{libgpiodcxx_soversion}
%{_libdir}/libgpiodcxx.so.*

%if %{with libgpiod_tests}
%files -n libgpiomockup%{libgpiomockup_soversion}
%{_libdir}/libgpiomockup.so.*
%endif

%files devel
%{_includedir}/*.h*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libgpiod.pc
%{_libdir}/pkgconfig/libgpiodcxx.pc

%files -n python-%{name}
%{python3_sitearch}/*.so

%changelog
* Thu Jun 13 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Replace *_number with *_soversion
* Thu Jun 13 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable build of tests (package gpiod-test and libgpiomockup) for Tumbleweed
* Thu Jun 13 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.4:
  * New features:
  - updated the testing framework to work with linux v5.1 in which the debugfs
    interface of the GPIO testing module changed in a backward incompatible way
  - factored out the code controlling the GPIO testing module into a separate
    shared library that may be reused by future testing executables for different
    language bindings
  - removed the --enable-install-tests build option and the make check target as
    they were redundant, subsequently tests are now installed as a normal program
    whenever they're enabled with --enable-tests
  * Improvements:
  - removed unnecessary std::move calls from C++ bindings
  - added the explicit keyword to bool() operators in C++ bindings
  * Bug fixes:
  - fix out of source build of man pages
* Fri Apr 12 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add conflicts with libgpiod1 to help upgrade
* Fri Apr  5 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- devel package now requires libgpiod and libgpiodcxx
* Fri Apr  5 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Move libgpiodcxx to its own package
* Wed Apr  3 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.3:
  * New features:
  - the gpio-tools now have automatically generated (using help2man) man pages
    that are bundled with the release tarball
  - support a singular 'default_val' argument in Line.request() in python
    bindings
  - the test executable can now be installed to the bindir along with the
    gpio-tools and the testing framework will look for the binaries in standard
    locations if it's not run from the top source directory
  - gpiomon now supports line buffered output
  * Improvements:
  - tweaks to the C API documentation
  - treewide unification of the naming of local variables
  - extended helptest in gpioset (explanation of the way the character device
    works aimed at reducing user confusion when a GPIO line reverts to its
    default value after gpioset exits)
  - the source directories have been rearranged and the src/ directory was
    dropped, lib/ and tools/ now live in the top source directory
  - minor coding style fixes in python bindings, ctxless functions and tools
  - automatically generated documentation is now removed by 'make clean'
  - all Makefiles now use top_builddir instead of relative paths
  - code shrink in configure.ac
  - add a brief section about API documentation to README
  * Bug fixes:
  - fix a segfault causing bug in C++ bindings
  - make bitset_cmp::operator() const as this is required by C++17
  - ignore 'remove' events from udev in the testing framework
  - don't segfault on num_lines = 0 in ctxless functions
* Mon Dec  3 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.2:
  * New features:
  - new contextless event monitor that should replace the previous event loop
    which caused problems on hardware that doesn't allow to watch both rising
    and falling edge events
  - port gpiomon to the new event monitor
  - deprecate event loop routines
  * Improvements:
  - many minor improvements and tweaks in the python module
  - new test cases for python bindings
  - add much more detailed documentation for python bindings
  - coding style improvements in gpio-tools
  - remove unicode characters from build scripts
  - improve the help text messages in gpio-tools
  - make gpiod_chip_open() and its variants verify that we're really trying to
    open a character device associated with a GPIO chip
  * Bug fixes:
  - fix memory leaks in python bindings
  - fix a memory corruption bug in python bindings
  - fix the default_vals argument in line request implementation in python
    bindings
  - fix a compilation warning in python bindings
  - fix gpiod_Chip_find_lines() for nonexistent lines (python bindings)
  - add a missing include in C++ bindings examples
  - correctly display the version string in gpio-tools
* Wed Sep  5 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add python binding
* Wed Sep  5 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.1.1:
  * Bug fixes:
  - fix memory leaks in python bindings
  - fix a memory corruption bug in python bindings
  - fix the default_vals argument in line request implementation in python
    bindings
  - fix a compilation warning in python bindings
* Sun Jul 29 2018 jengelh@inai.de
- Update RPM groups. Reorder sentences to put the library first,
  and the old sysfs interface last.
* Thu Jun 14 2018 guillaume.gardet@opensuse.org
- Add C++ bindings
* Thu Jun 14 2018 guillaume.gardet@opensuse.org
- Initial package version 1.1
